$(document).ready(function() {
	/*
	 * Quando abbiamo tutti gli elementi pronti, possiamo associare degli eventi
	 * Questo evento serve per chiudere tutti i menu eventualmente aperti
	 * Prima però di mettere il filtro, si guarda che non sia presente l'elemento
	 * con class barra-l, in modo da poter usare un callback diverso
	 */
	$('*').filter(function(index) {
		if($(this).parents('.barra-l').length>0)
			return false;
		if($(this).attr('class')=='barra-l')
			return false;
		return true;
	}).click(function() {
		// Chiudiamo i menu senza animazioni
		chiudiMenu();
		// Stoppo il Mouse Over (vedi sotto)
		menuMouseOverDisable();
	});
	/*
	 * Sovrascriviamo l'evento a tutti coloro che sono sotto barra-l
	 * anche se abbiamo evitato di dare loro l'evento.
	 * Diamo stopPropagation perché così non si verifica più l'evento che avverrebbe
	 * in quanto non abbiamo cliccato solo quell'elemento ma anche i suoi genitori
	 */
	$('.barra-l').click(function(event) {
		event.stopPropagation();
	});
	$('.barra-l').children().click(function(event) {
		event.stopPropagation();
	});
	/*
	 * Usiamo l'evento onclick per aprire o chiudere il menu
	 * jQuery ha anche toggle però capita che in questo caso un po' particolare
	 * si "incastri" perciò non lo usiamo. Usiamo click e lo cambiamo manualmente.
	 */
	$('.menu-item').click(function(event) {
		event.stopPropagation();
		apriMenu($(this));
	});
});
/*
 * Le funzioni che devono aprire e chiudere, visto che sono richiamate da eventi
 * non devono essere per forza dichiarate quando il DOM è pronto
 * Le funzioni sono:
 *  apriMenu con il parametro menu che è un oggetto jQuery
 *  chiudiMenuClick che è quella funzione che chiude un menu con animazione
 *  chiudiMenu che lo chiude senza animazioni e gli dà il css di default di nuovo
 *  menuContent che trova il menu content
 * il parametro menu deve essere o span.menu-item o div.menucontent o li contenente il menu
 */
function apriMenu(menu) {
	// Ottieni il div.menucontent di questo menu
	menu=menuContent(menu);
	// Chiudi gli altri menu trannne questo
	chiudiMenu(menu);
	/*
	 * Ora dobbiamo far vedere il menu.
	 * Se il menu è già visibile, è brutto che si possa espandere di nuovo,
	 * soprattutto se si usa un'animazione.
	 * Perciò vediamo se la proprietà CSS display è uguale a hidden o no
	 * È stato usato il metodo slideDown (trad. scivola giù perché il menu è in alto
	 * Tuttavia ci sono tanti metodi, come show
	 * C'è tutta la documentazione di jQuery al riguardo (in inglese):
	 *   http://api.jquery.com/category/effects/ 
	 */
	if($(menu).css('display')!='none') {
	} else
		$(menu).show();
	// Abilitiamo il Mouse Over (vedi sotto)
	menuMouseOverEnable();
	/*
	 * Visto che non si può usare toggle (vedi sopra), cambiamo manualmente
	 * la funzione da eseguire al click sugli span.
	 */
	$(menu).prev('.menu-item').unbind('click').click(function(event) {
		event.stopPropagation();
		chiudiMenuClick($(this));
	});
}
function chiudiMenuClick(menu) {
	/*
	 * Disabilitiamo per prima cosa il MouseOver poiché può capitare che uno
	 * riapra i menu passandoci sopra.
	 */
	menuMouseOverDisable()
	menu=menuContent(menu);
	$(menu).slideUp();
	/*
	 * La funzione slideUp ci mette un po' per chiudere il menu
	 * e succede che non venga eseguita se diamo subito chiudiMenu
	 * che è quella senza animazioni.
	 * Perciò la facciamo eseguire 410ms dopo perché il tempo di default
	 * di slideUp è di 400ms
	 */
	setTimeout(chiudiMenu, 405);
}
function chiudiMenu(menu) {
	// Tutti o DEVO ESCLUDERE un particolare menu?
	close=$('.barra-l .menucontent');
	if(typeof(menu)=='undefined') {
	} else {
		evita=menuContent(menu);
		close=close.filter(function(index){
			/*
			 * Questo serve per esempio per fare in modo da non aprire più volte
			 * lo stesso menu.
			 * Praticamente si fa dire un indice dei li della lista principale e lo confronta.
			 * Per indice si intende che numero di elemento di un genitore comune è.
			 */
			if($(evita).parent().index()==$(this).parent().index())
				return false; 
			return true;
		});
	}
	/*
	 * Il procedimento è il seguente:
	 *  1. Chiudo tutte le varie animazioni in corso
	 *  2. Nascondo il div
	 *  3. Gli ridò le proprietà di default
	 *  4. Gli dico che con il click deve aprire il menu
	 */
	$(close).stop().hide().css({
		'height' : 'auto'
	});
	$(close).prev('.menu-item').unbind('click').click(function(event) {
		event.stopPropagation();
		apriMenu($(this));
	});
	// Disabilitiamo il mouse over (vedi sotto)
	menuMouseOverDisable();
}
function menuContent(menu) {
	r=null;
	if(typeof(menu)=='undefined' || typeof(menu)=='null')
		return $();
	// Identifichiamo il div.menucontent
	if($(menu).hasClass('menu-item')) { // Span
		r=$(menu).next('.menucontent');
	} else if($(menu).hasClass('menucontent')) { // Direttamente il DIV
		r=$(menu);
	} else if(menu.nodeName=='li') { // Il li che li contiene
		r=$(menu).children('.menucontent');
	}
	return r;
}
/*
 * Quando apriamo un menu, visto che ne usiamo più di uno, 
 * facciamo che se sposti il mouse sopra un altro menu, si apra.
 * Tuttavia non serve che il DOM sia pronto perché bisogna poter 
 * attivare e disattivare questa funzione
 */
function menuMouseOverEnable() {
	$('.menu-item').mouseover(function() {
		apriMenu($(this));
	});
}
function menuMouseOverDisable() {
	$('.menu-item').unbind('mouseover');
}